@@ -15,7 +15,13 @@ class Route(object):
     See Route.__init__ docs for usage.
     
     """
-    def __init__(self, routepath, **kargs):
+    # reserved keys that don't count
+    reserved_keys = ['requirements']
+    
+    # special chars to indicate a natural split in the URL
+    done_chars = ('/', ',', ';', '.', '#')
+    
+    def __init__(self, name, routepath, **kargs):
         """Initialize a route, with a given routepath for
         matching/generation
         
@@ -24,12 +30,12 @@ class Route(object):
         Usage::
         
             >>> from routes.base import Route
-            >>> newroute = Route(':controller/:action/:id')
+            >>> newroute = Route(None, ':controller/:action/:id')
             >>> sorted(newroute.defaults.items())
             [('action', 'index'), ('id', None)]
-            >>> newroute = Route('date/:year/:month/:day',  
+            >>> newroute = Route(None, 'date/:year/:month/:day',  
             ...     controller="blog", action="view")
-            >>> newroute = Route('archives/:page', controller="blog", 
+            >>> newroute = Route(None, 'archives/:page', controller="blog", 
             ...     action="by_page", requirements = { 'page':'\d{1,2}' })
             >>> newroute.reqs
             {'page': '\\\d{1,2}'}
@@ -43,7 +49,7 @@ class Route(object):
         self.sub_domains = False
         self.prior = None
         self.redirect = False
-        self.name = None
+        self.name = name
         self.minimization = kargs.pop('_minimize', True)
         self.encoding = kargs.pop('_encoding', 'utf-8')
         self.reqs = kargs.get('requirements', {})
@@ -65,13 +71,7 @@ class Route(object):
         
         # Determine if explicit behavior should be used
         self.explicit = kargs.pop('_explicit', False)
-        
-        # reserved keys that don't count
-        reserved_keys = ['requirements']
-        
-        # special chars to indicate a natural split in the URL
-        self.done_chars = ('/', ',', ';', '.', '#')
-        
+                
         # Since static need to be generated exactly, treat them as
         # non-minimized
         if self.static:
@@ -80,10 +80,13 @@ class Route(object):
         
         # Strip preceding '/' if present, and not minimizing
         if routepath.startswith('/') and self.minimization:
-            routepath = routepath[1:]
+            self.routepath = routepath[1:]
+        self._kargs = kargs
+        self._setup_route()
         
+    def _setup_route(self):
         # Build our routelist, and the keys used in the route
-        self.routelist = routelist = self._pathkeys(routepath)
+        self.routelist = routelist = self._pathkeys(self.routepath)
         routekeys = frozenset([key['name'] for key in routelist \
                                if isinstance(key, dict)])
         
@@ -97,7 +100,7 @@ class Route(object):
         # Update our defaults and set new default keys if needed. defaults
         # needs to be saved
         (self.defaults, defaultkeys) = self._defaults(routekeys, 
-                                                      reserved_keys, kargs)
+                                                      self.reserved_keys, self._kargs)
         # Save the maximum keys we could utilize
         self.maxkeys = defaultkeys | routekeys
         
@@ -657,7 +660,7 @@ class Route(object):
                 val = kargs[key]
                 if isinstance(val, (tuple, list)):
                     for value in val:
-                        fragments.append((key, value))
+                        fragments.append((key, _str_encode(value, self.encoding)))
                 else:
                     fragments.append((key, _str_encode(val, self.encoding)))
             if fragments:
